@@ -439,8 +439,11 @@ class LoopSynthDef(SampleSynthDef):
         SampleSynthDef.__init__(self, "loop")
         self.pos = self.new_attr_instance("pos")
         self.sample = self.new_attr_instance("sample")
+        self.beat_stretch = self.new_attr_instance("beat_stretch")
         self.defaults['pos']   = 0
         self.defaults['sample']   = 0
+        self.defaults['beat_stretch'] = 0
+        self.base.append("rate = (rate * (1-(beat_stretch>0))) + ((BufDur.kr(buf) / sus) * (beat_stretch>0));")
         self.base.append("osc = PlayBuf.ar(2, buf, BufRateScale.kr(buf) * rate, startPos: BufSampleRate.kr(buf) * pos, loop: 1.0);")
         self.base.append("osc = osc * EnvGen.ar(Env([0,1,1,0],[0.05, sus-0.05, 0.05]));")
         self.osc = self.osc * self.amp
